@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.ChimeSDKMeetings 1.21.14\nVersion:         1.21.14\nBuilder"
-        " version: 7.3.0\nDocs:           "
+        "Type annotations for boto3.ChimeSDKMeetings 1.21.23\nVersion:        "
+        " 1.21.23.post1\nBuilder version: 7.4.0\nDocs:           "
         " https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings//\nBoto3 docs:    "
         "  https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.21.14")
+    print("1.21.23.post1")
 
 
 def main() -> None:
