@@ -106,7 +106,8 @@ class ChimeSDKMeetingsClient(BaseClient):
         ExternalMeetingId: str,
         MeetingHostId: str = ...,
         NotificationsConfiguration: "NotificationsConfigurationTypeDef" = ...,
-        MeetingFeatures: "MeetingFeaturesConfigurationTypeDef" = ...
+        MeetingFeatures: "MeetingFeaturesConfigurationTypeDef" = ...,
+        PrimaryMeetingId: str = ...
     ) -> CreateMeetingResponseTypeDef:
         """
         Creates a new Amazon Chime SDK meeting in the specified media Region with no
@@ -125,7 +126,8 @@ class ChimeSDKMeetingsClient(BaseClient):
         Attendees: Sequence["CreateAttendeeRequestItemTypeDef"],
         MeetingHostId: str = ...,
         MeetingFeatures: "MeetingFeaturesConfigurationTypeDef" = ...,
-        NotificationsConfiguration: "NotificationsConfigurationTypeDef" = ...
+        NotificationsConfiguration: "NotificationsConfigurationTypeDef" = ...,
+        PrimaryMeetingId: str = ...
     ) -> CreateMeetingWithAttendeesResponseTypeDef:
         """
         Creates a new Amazon Chime SDK meeting in the specified media Region, with
